

[![DOI](https://zenodo.org/badge/192689060.svg)](https://zenodo.org/badge/latestdoi/192689060)


# Just Another Noise 2 Noise Implementation (JANNI)
Just another noise 2 noise implementation (JANNI) with Keras for cryo-em data.

All documentation can be found here:
http://sphire.mpg.de/wiki/doku.php?id=janni
